@@ -19,6 +19,7 @@ from deepdiff import DeepDiff
 import os
 import sys
 import re
+import copy
 import importlib
 
 
@@ -44,6 +45,7 @@ def gather_test_dirs(task):
         tests = [d for d in os.listdir(os.path.join(DATA_DIR, task)) if re.findall(r'test_.+', d)]
     return tests
 
+
 def gather_tests():
     tests = []
     for task in get_task_names():
@@ -52,6 +54,45 @@ def gather_tests():
     return tests
 
 
+def bytes_to_string(data):
+    if isinstance(data, list):
+        return [bytes_to_string(element) for element in data]
+    elif isinstance(data, dict):
+        return {key: bytes_to_string(value) for key, value in data.items()}
+    if isinstance(data, bytes):
+        return str(data.hex())
+    else:
+        return data
+
+
+def create_comparable_request(data):
+    data['kwargs'].pop('headers', None)
+    data = bytes_to_string(data)
+    return data
+
+
+def get_test_config(task, test):
+    """
+    Get the config for the test
+    """
+    file_path = f'{DATA_DIR}/{task}/{test}/config.json'
+    config = {}
+    if os.path.exists(file_path):
+        config = json.load(open(file_path, 'r'))
+    return config
+
+
+def get_mock_data(task, test):
+    """
+    Get the mock data for the test
+    """
+    file_path = f'{DATA_DIR}/{task}/{test}/mocks.json'
+    mocks = []
+    if os.path.exists(file_path):
+        mocks = json.load(open(file_path, 'r'))
+    return mocks
+
+
 def build_mock(mock_definitions, auth_endpoints):
 
     def mock_handler(self, *args, **kwargs):
@@ -59,7 +100,8 @@ def build_mock(mock_definitions, auth_endpoints):
             "args": list(args),
             "kwargs": kwargs
         }
-        comparable['kwargs'].pop('headers', None)
+        comparable = create_comparable_request(comparable)
+
         if auth_endpoints and any([endpoint in args[1] for endpoint in auth_endpoints]):
             comparable['kwargs'] = {}
         for request in mock_definitions:
@@ -74,7 +116,10 @@ def build_mock(mock_definitions, auth_endpoints):
 def mock_session(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
-        if args[0].mock_requests:
+        if func.__name__.startswith("test") and args[0].test_config.get("mock_requests")\
+                and not args[0].global_config.get("mock_requests"):
+            print("Test override: forcing mock_requests")
+        if args[0].config.get('mock_requests', False):
             with patch.object(Session, 'request', build_mock(args[0].mocks, args[0].config['auth_endpoints'])):
                 return func(*args, **kwargs)
         return func(*args, **kwargs)
@@ -97,12 +142,14 @@ def sw_main(task, _inputs, _asset):
 class TestStandardRest:
 
     @pytest.fixture(autouse=True)
-    def _set_ctx(self, task, test, mock_data, mock_requests, config):
+    def _set_ctx(self, task, test, config):
         self.task = task
         self.test = test
-        self.mocks = mock_data
-        self.mock_requests = mock_requests
-        self.config = config
+        self.mocks = get_mock_data(task, test)
+        self.test_config = get_test_config(task, test)
+        self.global_config = config
+        self.config = copy.deepcopy(self.global_config)
+        self.config.update(self.test_config)
         self.ctx = self.cls(task, test)
 
     @mock_session
@@ -138,7 +185,6 @@ class TestStandardRest:
         """
         resp = self.ctx.execute()
         assert self.validate_output_manifest(resp)
-        assert DeepDiff(resp, json.load(open(f'{DATA_DIR}/{self.task}/{self.test}/output.json'))) == {}
 
     def validate_output_manifest(self, resp, *args, **kwargs):
         """
